<h4> Here are some organizations that have used SeleniumBase:</h4>

* [HubSpot](https://www.hubspot.com/)
* [Veracode](https://www.veracode.com/)
* [Autodesk](https://www.autodesk.com/)
* [iboss cloud](https://www.iboss.com/)
* [CA Technologies](https://www.ca.com/)
* [Broadcom](https://www.broadcom.com/)
* [MIT](https://web.mit.edu/)
* [Harvard Medical School](https://hms.harvard.edu/)
* [Mississippi State University](https://www.msstate.edu/)
* [Queen's University](https://www.queensu.ca/)
* [L1NNA Laboratory](https://l1nna.com/)
* [First American](https://www.firstam.com/)
* [StreamSets](https://streamsets.com/)
* [Akamai](https://www.akamai.com/)
* [VMware](https://www.vmware.com/)
* [Baidu](https://www.baidu.com/)
* [Yandex](https://yandex.ru/)
* [HqO](https://www.hqo.co/)
* [Jana](https://www.crunchbase.com/organization/jana)
* [Raid The Room](http://raidtheroom.com/)
* [Thoma Bravo](https://www.thomabravo.com/)
* [GeoNode](http://geonode.org/)
* And more...

<h3>Case Study: (<i>HubSpot</i>)</h3>

In addition to using SeleniumBase for testing the UI of their content management system, HubSpot used SeleniumBase to automate the migration of website pages from their old CMS to their new one, which saved them over one million USD and a significant amount of time.

Learn how HubSpot uses SeleniumBase for website testing by reading: [Automated Testing with Selenium](https://dev.hubspot.com/blog/bid/88880/Automated-Integration-Testing-with-Selenium-at-HubSpot#hs_cos_wrapper_name)

For more reading about automation at HubSpot, see: [The Classic "QA Team" is Obsolete](https://product.hubspot.com/blog/the-classic-qa-team-is-obsolete#hs_cos_wrapper_name)
